import {
  csv,
  format,
  select
} from 'd3';

import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';


const svg = select('svg');

const width = +svg.attr('width'),
      height = +svg.attr('height');

let data,
    dataColumns,
    xColumn,
    yColumn;

const render = () => {

  const onXColumnClicked = column => {
    xColumn = column;
    render();
  }  
  const onYColumnClicked = column => {
    yColumn = column;
    render();
  }

  select('.x-menu')
    .call(dropdownMenu, {
      options: dataColumns,
    	onOptionClick: onXColumnClicked,
    	initialValue: xColumn
    });
  
  select('.y-menu')
    .call(dropdownMenu, {
      options: dataColumns,
    	onOptionClick: onYColumnClicked,
    	initialValue: yColumn
    });

  
  svg.call(scatterPlot, {
    data,
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    yAxisLabel: yColumn,
    circleRadius: 5,
    margin: {top: 60, right: 40, bottom: 60, left: 120},
    width,
    height
  });
  
};


csv('data.csv')
  .then(loadedData => {
  	data = loadedData;
  
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    });
  
  	dataColumns = data.columns.sort()
  
  	xColumn = dataColumns[4];
  	yColumn = dataColumns[2];
    	
    render();
  });

